gedidb.beam\_handler
====================

.. currentmodule:: gedidb

.. autoclass:: beam_handler

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~beam_handler.__init__
      ~beam_handler.apply_filter
      ~beam_handler.build_virtual_dataset
      ~beam_handler.clear
      ~beam_handler.copy
      ~beam_handler.create_dataset
      ~beam_handler.create_dataset_like
      ~beam_handler.create_group
      ~beam_handler.create_virtual_dataset
      ~beam_handler.get
      ~beam_handler.items
      ~beam_handler.keys
      ~beam_handler.move
      ~beam_handler.pop
      ~beam_handler.popitem
      ~beam_handler.require_dataset
      ~beam_handler.require_group
      ~beam_handler.setdefault
      ~beam_handler.update
      ~beam_handler.values
      ~beam_handler.visit
      ~beam_handler.visit_links
      ~beam_handler.visititems
      ~beam_handler.visititems_links
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~beam_handler.attrs
      ~beam_handler.beam_type
      ~beam_handler.field_mapper
      ~beam_handler.file
      ~beam_handler.id
      ~beam_handler.main_data
      ~beam_handler.n_shots
      ~beam_handler.name
      ~beam_handler.parent
      ~beam_handler.ref
      ~beam_handler.regionref
   
   